@@ -74,7 +74,7 @@ class EnumlibAdaptor(object):
 
     def __init__(self, structure, min_cell_size=1, max_cell_size=1,
                  symm_prec=0.1, enum_precision_parameter=0.001,
-                 refine_structure=False):
+                 refine_structure=False, check_ordered_symmetry=True):
         """
         Initializes the adapter with a structure and some parameters.
 
@@ -95,6 +95,14 @@ class EnumlibAdaptor(object):
                 issues in enumlib. If you are already starting from an
                 experimental cif, refinement should have already been done and
                 it is not necessary. Defaults to False.
+            check_ordered_symmetry (bool): Whether to check the symmetry of
+                the ordered sites. If the symmetry of the ordered sites is
+                lower, the lowest symmetry ordered sites is included in the
+                enumeration. This is important if the ordered sites break
+                symmetry in a way that is important getting possible
+                structures. But sometimes including ordered sites
+                slows down enumeration to the point that it cannot be
+                completed. Switch to False in those cases. Defaults to True.
         """
         if refine_structure:
             finder = SpacegroupAnalyzer(structure, symm_prec)
@@ -105,6 +113,7 @@ class EnumlibAdaptor(object):
         self.max_cell_size = max_cell_size
         self.symm_prec = symm_prec
         self.enum_precision_parameter = enum_precision_parameter
+        self.check_ordered_symmetry = check_ordered_symmetry
 
     def run(self):
         """
@@ -206,15 +215,16 @@ class EnumlibAdaptor(object):
         self.ordered_sites = []
         to_add = []
 
-        for sites in ordered_sites:
-            temp_sites = list(curr_sites) + sites
-            sgnum = get_sg_info(temp_sites)
-            if sgnum < min_sgnum:
-                logger.debug("Adding {} to sites to be ordered. "
-                             "New sgnum {}"
-                             .format(sites, sgnum))
-                to_add = sites
-                min_sgnum = sgnum
+        if self.check_ordered_symmetry:
+            for sites in ordered_sites:
+                temp_sites = list(curr_sites) + sites
+                sgnum = get_sg_info(temp_sites)
+                if sgnum < min_sgnum:
+                    logger.debug("Adding {} to sites to be ordered. "
+                                 "New sgnum {}"
+                                 .format(sites, sgnum))
+                    to_add = sites
+                    min_sgnum = sgnum
 
         for sites in ordered_sites:
             if sites == to_add:
@@ -245,19 +255,22 @@ class EnumlibAdaptor(object):
         output.append("{} {}".format(self.min_cell_size, self.max_cell_size))
         output.append(str(self.enum_precision_parameter))
         output.append("partial")
+
+        ndisordered = sum([len(s) for s in disordered_sites])
+        base = ndisordered #10 ** int(math.ceil(math.log10(ndisordered)))
         #To get a reasonable number of structures, we fix concentrations to the
         #range expected in the original structure.
         total_amounts = sum(index_amounts)
         for amt in index_amounts:
             conc = amt / total_amounts
-            if abs(conc * 1000 - round(conc * 1000)) < 1e-5:
-                output.append("{} {} {}".format(int(round(conc * 1000)),
-                                                int(round(conc * 1000)),
-                                                1000))
+            if abs(conc * base - round(conc * base)) < 1e-5:
+                output.append("{} {} {}".format(int(round(conc * base)),
+                                                int(round(conc * base)),
+                                                base))
             else:
-                min_conc = int(math.floor(conc * 1000))
+                min_conc = int(math.floor(conc * base))
                 output.append("{} {} {}".format(min_conc - 1, min_conc + 1,
-                                                1000))
+                                                base))
         output.append("")
         logger.debug("Generated input file:\n{}".format("\n".join(output)))
         with open("struct_enum.in", "w") as f:
