@@ -2,5 +2,5 @@ from .eos import *
 from .pseudos import *
 from .netcdf import *
 from .tasks import *
-from .workflows import *
+from .works import *
 from .calculations import *
