@@ -11,17 +11,21 @@ import collections
 import warnings
 import shutil
 import pickle
+import copy
+import numpy as np
 
 from six.moves import map 
+from atomicfile import AtomicFile
 from pprint import pprint
 from prettytable import PrettyTable
 from monty.io import FileLock
 from monty.termcolor import cprint, colored, stream_has_colours
 from pymatgen.serializers.pickle_coders import pmg_pickle_load, pmg_pickle_dump 
-from .tasks import Dependency, Status, Node, NodeResults, Task, ScfTask, PhononTask, TaskManager
+from .tasks import Dependency, Status, Node, NodeResults, Task, ScfTask, PhononTask, TaskManager, NscfTask, DdkTask
+from .tasks import AnaddbTask, DdeTask
 from .utils import Directory, Editor
 from .abiinspect import yaml_read_irred_perts
-from .workflows import Workflow, BandStructureWorkflow, PhononWorkflow, G0W0_Workflow, QptdmWorkflow
+from .works import Work, BandStructureWork, PhononWork, G0W0Work, QptdmWork
 
 try:
     from pydispatch import dispatcher
@@ -38,7 +42,7 @@ __maintainer__ = "Matteo Giantomassi"
 
 
 __all__ = [
-    "AbinitFlow",
+    "Flow",
     "G0W0WithQptdmFlow",
     "bandstructure_flow",
     "g0w0_flow",
@@ -55,7 +59,7 @@ class FlowResults(NodeResults):
 
     @classmethod
     def from_node(cls, flow):
-        """Initialize an instance from a WorkFlow instance."""
+        """Initialize an instance from a Work instance."""
         new = super(FlowResults, cls).from_node(flow)
 
         #new.update(
@@ -73,19 +77,16 @@ class FlowResults(NodeResults):
         return new
 
 
-class AbinitFlow(Node):
+class Flow(Node):
     """
-    This object is a container of workflows. Its main task is managing the 
-    possible inter-depedencies among the workflows and the creation of
+    This object is a container of work. Its main task is managing the 
+    possible inter-depedencies among the work and the creation of
     dynamic worfflows that are generates by callbacks registered by the user.
 
     .. attributes:
 
-        creation_date:
-            String with the creation_date
-
-        pickle_protocol: 
-            Protocol for Pickle database (default: -1 i.e. latest protocol)
+        creation_date: String with the creation_date
+        pickle_protocol: Protocol for Pickle database (default: -1 i.e. latest protocol)
     """
     VERSION = "0.1"
     PICKLE_FNAME = "__AbinitFlow__.pickle"
@@ -95,17 +96,14 @@ class AbinitFlow(Node):
     def __init__(self, workdir, manager=None, pickle_protocol=-1):
         """
         Args:
-            workdir:
-                String specifying the directory where the workflows will be produced.
-            manager:
-                `TaskManager` object responsible for the submission of the jobs.
-                If manager is None, the object is initialized from the yaml file
-                located either in the working directory or in the user configuration dir.
-            pickle_procol:
-                Pickle protocol version used for saving the status of the object.
-                -1 denotes the latest version supported by the python interpreter.
+            workdir: String specifying the directory where the works will be produced.
+            manager: :class:`TaskManager` object responsible for the submission of the jobs.
+                     If manager is None, the object is initialized from the yaml file
+                     located either in the working directory or in the user configuration dir.
+            pickle_procol: Pickle protocol version used for saving the status of the object.
+                          -1 denotes the latest version supported by the python interpreter.
         """
-        super(AbinitFlow, self).__init__()
+        super(Flow, self).__init__()
 
         self.set_workdir(workdir)
 
@@ -114,7 +112,7 @@ class AbinitFlow(Node):
         if manager is None: manager = TaskManager.from_user_config()
         self.manager = manager.deepcopy()
 
-        # List of workflows.
+        # List of works.
         self._works = []
 
         self._waited = 0
@@ -182,13 +180,11 @@ class AbinitFlow(Node):
         Loads the object from a pickle file and performs initial setup.
 
         Args:
-            filepath:
-                Filename or directory name. It filepath is a directory, we 
+            filepath: Filename or directory name. It filepath is a directory, we
                 scan the directory tree starting from filepath and we 
                 read the first pickle database. Raise RuntimeError if multiple
                 databases are found.
-            disable_signals:
-                If True, the nodes of the flow are not connected by signals.
+            disable_signals: If True, the nodes of the flow are not connected by signals.
                 This option is usually used when we want to read a flow 
                 in read-only mode and we want to avoid any possible side effect.
         """
@@ -209,8 +205,6 @@ class AbinitFlow(Node):
 
         with FileLock(filepath):
             with open(filepath, "rb") as fh:
-                #flow = pickle.load(fh)
-                #flow = PmgUnpickler(fh).load()
                 flow = pmg_pickle_load(fh)
 
         # Check if versions match.
@@ -263,12 +257,12 @@ class AbinitFlow(Node):
 
     @property
     def works(self):
-        """List of `Workflow` objects contained in self.."""
+        """List of :class:`Work` objects contained in self.."""
         return self._works
 
     @property
     def all_ok(self):
-        """True if all the tasks in workflows have reached S_OK."""
+        """True if all the tasks in works have reached `S_OK`."""
         return all(work.all_ok for work in self)
 
     @property
@@ -306,7 +300,7 @@ class AbinitFlow(Node):
         Returns a `Counter` object that counts the number of tasks with 
         given status (use the string representation of the status as key).
         """
-        # Count the number of tasks with given status in each workflow.
+        # Count the number of tasks with given status in each work.
         counter = self[0].status_counter
         for work in self[1:]:
             counter += work.status_counter
@@ -354,11 +348,11 @@ class AbinitFlow(Node):
 
     def chroot(self, new_workdir):
         """
-        Change the workir of the `Flow`. Mainly used for
+        Change the workir of the :class:`Flow`. Mainly used for
         allowing the user to open the GUI on the local host
         and access the flow from remote via sshfs.
 
-        .. note:
+        .. note::
             Calling this method will make the flow go in read-only mode.
         """
         self._chrooted_from = self.workdir
@@ -385,24 +379,24 @@ class AbinitFlow(Node):
     def iflat_tasks_wti(self, status=None, op="=="):
         """
         Generator to iterate over all the tasks of the `Flow`.
-        Yields
+        Yields:
 
             (task, work_index, task_index)
 
         If status is not None, only the tasks whose status satisfies
         the condition (task.status op status) are selected
-        status can be either one of the flags defined in the `Task` class 
+        status can be either one of the flags defined in the :class:`Task` class
         (e.g Task.S_OK) or a string e.g "S_OK" 
         """
         return self._iflat_tasks_wti(status=status, op=op, with_wti=True)
 
     def iflat_tasks(self, status=None, op="=="):
         """
-        Generator to iterate over all the tasks of the `Flow`.
+        Generator to iterate over all the tasks of the :class:`Flow`.
 
         If status is not None, only the tasks whose status satisfies
         the condition (task.status op status) are selected
-        status can be either one of the flags defined in the `Task` class 
+        status can be either one of the flags defined in the :class:`Task` class
         (e.g Task.S_OK) or a string e.g "S_OK" 
         """
         return self._iflat_tasks_wti(status=status, op=op, with_wti=False)
@@ -473,7 +467,7 @@ class AbinitFlow(Node):
     #    return deadlocked
 
     def check_status(self):
-        """Check the status of the workflows in self."""
+        """Check the status of the works in self."""
         for work in self:
             work.check_status()
 
@@ -481,7 +475,7 @@ class AbinitFlow(Node):
 
     @property
     def status(self):
-        """The status of the flow i.e. the minimum of the status of its tasks and its works"""
+        """The status of the Flow i.e. the minimum of the status of its tasks and its works"""
         return min(work.get_all_status(only_min=True) for work in self)
 
     def fix_critical(self):
@@ -490,7 +484,7 @@ class AbinitFlow(Node):
 
     def fix_abi_critical(self):
         """
-        Fixer for critical events originating form abinit
+        Fixer for critical events originating from abinit
         """
         for task in self.iflat_tasks(status=Task.S_ABICRITICAL):
             #todo
@@ -517,7 +511,7 @@ class AbinitFlow(Node):
             if not task.queue_errors:
                 # queue error but no errors detected, try to solve by increasing resources
                 # if resources are at maximum the tast is definitively turned to errored
-                if self.manager.increase_resources():  # acts either on the policy or on the qadapter
+                if task.manager.increase_resources():  # acts either on the policy or on the qadapter
                     task.reset_from_scratch()
                     return True
                 else:
@@ -576,10 +570,9 @@ class AbinitFlow(Node):
                         logger.debug(info_msg)
                         return task.set_status(task.S_ERROR, info_msg)
 
-    def show_status(self, stream=sys.stdout, verbose=0):
+    def show_status(self, stream=sys.stdout, verbose=1):
         """
-        Report the status of the workflows and the status 
-        of the different tasks on the specified stream.
+        Report the status of the works and the status  of the different tasks on the specified stream.
 
         if not verbose, no full entry for works that are completed is printed.
         """
@@ -588,10 +581,10 @@ class AbinitFlow(Node):
 
         for i, work in enumerate(self):
             print(80*"=", file=stream)
-            print("Workflow #%d: %s, Finalized=%s\n" % (i, work, work.finalized), file=stream)
+            print("Work #%d: %s, Finalized=%s\n" % (i, work, work.finalized), file=stream)
 
-            if verbose == 0 and work.finalized:
-                continue
+            #if work.finalized and not verbose:
+            #    continue
 
             table =PrettyTable([
                 "Task", "Status", "Queue-id", "Errors", "Warnings", "Comments", 
@@ -616,10 +609,10 @@ class AbinitFlow(Node):
                     tot_num_errors += 1
                     task_name = colored(task_name, red)
 
-                table.add_row(
-                    [task_name, str(task.status), str(task.queue_id)] +  events + 
-                    cpu_info + task_info
-                )
+                if has_colours:
+                    table.add_row([task_name, task.status.colored, str(task.queue_id)] +  events + cpu_info + task_info)
+                else:
+                    table.add_row([task_name, str(task.status), str(task.queue_id)] +  events + cpu_info + task_info)
 
             # Print table and write colorized line with the total number of errors.
             print(table, file=stream)
@@ -665,12 +658,12 @@ class AbinitFlow(Node):
 
     @property
     def has_db(self):
-        """True if flow uses MongoDB to store the results."""
+        """True if flow uses `MongoDB` to store the results."""
         return self.manager.has_db
 
     def db_insert(self):
         """
-        Insert results in the mongdob database.
+        Insert results in the `MongDB` database.
         """
         assert self.has_db
         # Connect to MongoDb and get the collection.
@@ -706,9 +699,8 @@ class AbinitFlow(Node):
         Open the files of the flow inside an editor (command line interface).
 
         Args:
-            what:
-                string with the list of characters selecting the file type
-                Possible choices:
+            what: string with the list of characters selecting the file type
+                  Possible choices:
                     i ==> input_file,
                     o ==> output_file,
                     f ==> files_file,
@@ -716,16 +708,12 @@ class AbinitFlow(Node):
                     l ==> log_file,
                     e ==> stderr_file,
                     q ==> qerr_file,
-            wti:
-                tuple with the (work, task_index) to select
-                or string in the form w_start:w_stop,task_start:task_stop
-            status:
-                if not None, only the tasks with this status are select
-            op:
-                status operator. Requires status. A task is selected 
+            wti: tuple with the (work, task_index) to select
+                 or string in the form w_start:w_stop,task_start:task_stop
+            status: if not None, only the tasks with this status are select
+            op: status operator. Requires status. A task is selected
                 if task.status op status evaluates to true.
-            editor:
-                Select the editor. None to use the default editor ($EDITOR shell env var)
+            editor: Select the editor. None to use the default editor ($EDITOR shell env var)
         """
         #TODO: Add support for wti
         if wti is not None:
@@ -794,6 +782,15 @@ class AbinitFlow(Node):
 
         return num_cancelled
 
+    def get_njobs_in_queue(self, username=None):
+        """
+        returns the number of jobs in the queue, None when the number of jobs cannot be determined.
+
+        Args:
+            username: (str) the username of the jobs to count (default is to autodetect)
+        """
+        return self.manager.qadapter.get_njobs_in_queue(username=username)
+
     def rmtree(self, ignore_errors=False, onerror=None):
         """Remove workdir (same API as shutil.rmtree)."""
         shutil.rmtree(self.workdir, ignore_errors=ignore_errors, onerror=onerror)
@@ -810,9 +807,7 @@ class AbinitFlow(Node):
     def build_and_pickle_dump(self):
         """
         Build dirs and file of the `Flow` and save the object in pickle format.
-
-        Returns:
-            0 if success
+        Returns 0 if success
         """
         self.build()
         return self.pickle_dump()
@@ -820,9 +815,7 @@ class AbinitFlow(Node):
     def pickle_dump(self):
         """
         Save the status of the object in pickle format.
-
-        Returns:
-            0 if success
+        Returns 0 if success
         """
         if self.has_chrooted:
             warnings.warn("Cannot pickle_dump since we have chrooted from %s" % self.has_chrooted)
@@ -831,81 +824,51 @@ class AbinitFlow(Node):
         protocol = self.pickle_protocol
         filepath = os.path.join(self.workdir, self.PICKLE_FNAME)
 
+        # Atomic transaction with FileLock.
         with FileLock(filepath):
-            with open(filepath, mode="w" if protocol == 0 else "wb") as fh:
-                #pickle.dump(self, fh, protocol=protocol)
-                #PmgPickler(fh, protocol=protocol).dump(self)
+            #with open(filepath, mode="wb") as fh:
+            with AtomicFile(filepath, mode="wb") as fh:
                 pmg_pickle_dump(self, fh, protocol=protocol)
 
-        # Atomic transaction.
-        #filepath_new = filepath + ".new"
-        #filepath_save = filepath + ".save"
-        #shutil.copyfile(filepath, filepath_save)
-
-        #try:
-        #    with open(filepath_new, mode="w" if protocol == 0 else "wb") as fh:
-        #        pickle.dump(self, fh, protocol=protocol)
-
-        #    os.rename(filepath_new, filepath)
-        #except IOError:
-        #    os.rename(filepath_save, filepath)
-        #finally:
-        #    try
-        #        os.remove(filepath_save)
-        #    except:
-        #        pass
-        #    try
-        #        os.remove(filepath_new)
-        #    except:
-        #        pass
         return 0
 
     def register_task(self, input, deps=None, manager=None, task_class=None):
         """
-        Utility function that generates a `Workflow` made of a single task
+        Utility function that generates a `Work` made of a single task
 
         Args:
-            input:
-                Abinit Input file or `Strategy` object of `Task` object.
-            deps:
-                List of `Dependency` objects specifying the dependency of this node.
-                An empy list of deps implies that this node has no dependencies.
-            manager:
-                The `TaskManager` responsible for the submission of the task. 
-                If manager is None, we use the `TaskManager` specified during the creation of the workflow.
-            task_class:
-                Task subclass to instantiate. Default: `AbinitTask` 
+            input: :class:`AbinitInput` or :class:`Strategy` object.
+            deps: List of :class:`Dependency` objects specifying the dependency of this node.
+                  An empy list of deps implies that this node has no dependencies.
+            manager: The :class:`TaskManager` responsible for the submission of the task.
+                     If manager is None, we use the :class:`TaskManager` specified during the creation of the work.
+            task_class: Task subclass to instantiate. Default: :class:`AbinitTask`
 
         Returns:   
             The generated `Task`.
         """
-        work = Workflow(manager=manager)
+        work = Work(manager=manager)
         task = work.register(input, deps=deps, task_class=task_class)
         self.register_work(work)
 
-        return task
+        return work
 
     def register_work(self, work, deps=None, manager=None, workdir=None):
         """
-        Register a new `Workflow` and add it to the internal list, 
-        taking into account possible dependencies.
+        Register a new :class:`Work` and add it to the internal list, taking into account possible dependencies.
 
         Args:
-            work:
-                `Workflow` object.
-            deps:
-                List of `Dependency` objects specifying the dependency of this node.
-                An empy list of deps implies that this node has no dependencies.
-            manager:
-                The `TaskManager` responsible for the submission of the task. 
-                If manager is None, we use the `TaskManager` specified during the creation of the workflow.
-            workdir:
-                The name of the directory used for the `Workflow`.
+            work: :class:`Work` object.
+            deps: List of :class:`Dependency` objects specifying the dependency of this node.
+                  An empy list of deps implies that this node has no dependencies.
+            manager: The :class:`TaskManager` responsible for the submission of the task.
+                     If manager is None, we use the `TaskManager` specified during the creation of the work.
+            workdir: The name of the directory used for the :class:`Work`.
 
         Returns:   
-            The registered `Workflow`.
+            The registered :class:`Work`.
         """
-        # Directory of the workflow.
+        # Directory of the work.
         if workdir is None:
             work_workdir = os.path.join(self.workdir, "w" + str(len(self)))
         else:
@@ -926,29 +889,24 @@ class AbinitFlow(Node):
 
     def register_work_from_cbk(self, cbk_name, cbk_data, deps, work_class, manager=None):
         """
-        Registers a callback function that will generate the Tasks of the `Workflow`.
+        Registers a callback function that will generate the Task of the `Work`.
 
         Args:
-            cbk_name:
-                Name of the callback function (must be a bound method of self)
-            cbk_data
-                Additional data passed to the callback function.
-            deps:
-                List of `Dependency` objects specifying the dependency of the workflow.
-            work_class:
-                `Workflow` class to instantiate.
-            manager:
-                The `TaskManager` responsible for the submission of the task. 
-                If manager is None, we use the `TaskManager` specified during the creation of the `Flow`.
+            cbk_name: Name of the callback function (must be a bound method of self)
+            cbk_data: Additional data passed to the callback function.
+            deps: List of :class:`Dependency` objects specifying the dependency of the work.
+            work_class: :class:`Work` class to instantiate.
+            manager: The :class:`TaskManager` responsible for the submission of the task.
+                    If manager is None, we use the `TaskManager` specified during the creation of the :class:`Flow`.
                                                                                                             
         Returns:   
-            The `Workflow` that will be finalized by the callback.
+            The :class:`Work` that will be finalized by the callback.
         """
-        # TODO: pass a workflow factory instead of a class
-        # Directory of the workflow.
+        # TODO: pass a Work factory instead of a class
+        # Directory of the Work.
         work_workdir = os.path.join(self.workdir, "w" + str(len(self)))
 
-        # Create an empty workflow and register the callback
+        # Create an empty work and register the callback
         work = work_class(workdir=work_workdir, manager=manager)
         
         self._works.append(work)
@@ -960,7 +918,7 @@ class AbinitFlow(Node):
         work.add_deps(deps)
 
         # Wrap the callable in a Callback object and save 
-        # useful info such as the index of the workflow and the callback data.
+        # useful info such as the index of the work and the callback data.
         cbk = FlowCallback(cbk_name, self, deps=deps, cbk_data=cbk_data)
         self._callbacks.append(cbk)
                                                                                                             
@@ -968,14 +926,14 @@ class AbinitFlow(Node):
 
     def allocate(self):
         """
-        Allocate the `AbinitFlow` i.e. assign the `workdir` and (optionally) 
-        the `TaskManager` to the different tasks in the Flow.
+        Allocate the `Flow` i.e. assign the `workdir` and (optionally) 
+        the :class:`TaskManager` to the different tasks in the Flow.
         """
         for work in self:
-            # Each workflow has a reference to its flow.
+            # Each work has a reference to its flow.
             work.allocate(manager=self.manager)
             work.set_flow(self)
-            # Each task has a reference to its workflow.
+            # Each task has a reference to its work.
             for task in work:
                 task.set_work(work)
 
@@ -983,14 +941,23 @@ class AbinitFlow(Node):
 
         return self
 
-    def show_dependencies(self):
-        for work in self:
-            work.show_intrawork_deps()
+    def show_dependencies(self, stream=sys.stdout):
+        """Writes to the given stream the ASCII representation of the dependency tree."""
+        #for work in self: work.show_intrawork_deps()
+        def child_iter(node):
+            return [d.node for d in node.deps]
+
+        def text_str(node):
+            return colored(str(node), color=node.status.color_opts["color"])
+
+        from monty.pprint import draw_tree
+        for task in self.iflat_tasks():
+            print(draw_tree(task, child_iter, text_str), file=stream)
 
     def on_dep_ok(self, signal, sender):
         # TODO
         # Replace this callback with dynamic dispatch
-        # on_all_S_OK for workflow
+        # on_all_S_OK for work
         # on_S_OK for task
         logger.info("on_dep_ok with sender %s, signal %s" % (str(sender), signal))
 
@@ -1017,11 +984,11 @@ class AbinitFlow(Node):
 
     def connect_signals(self):
         """
-        Connect the signals within the workflow.
+        Connect the signals within the work.
         self is responsible for catching the important signals raised from 
         its task and raise new signals when some particular condition occurs.
         """
-        # Connect the signals inside each Workflow.
+        # Connect the signals inside each Work.
         for work in self:
             work.connect_signals()
 
@@ -1032,11 +999,11 @@ class AbinitFlow(Node):
                 dispatcher.connect(self.on_dep_ok, signal=dep.node.S_OK, sender=dep.node, weak=False)
 
         # Associate to each signal the callback _on_signal
-        # (bound method of the node that will be called by `AbinitFlow`
+        # (bound method of the node that will be called by `Flow`
         # Each node will set its attribute _done_signal to True to tell
         # the flow that this callback should be disabled.
 
-        # Register the callbacks for the Workflows.
+        # Register the callbacks for the Work.
         #for work in self:
         #    slot = self._sig_slots[work]
         #    for signal in S_ALL:
@@ -1065,9 +1032,8 @@ class AbinitFlow(Node):
 
     def rapidfire(self, check_status=False, **kwargs):
         """
-        Use PyLauncher to submits tasks in rapidfire mode.
+        Use :class:`PyLauncher` to submits tasks in rapidfire mode.
         kwargs contains the options passed to the launcher.
-
         Return the number of tasks submitted.
         """
         from .launcher import PyLauncher
@@ -1084,7 +1050,7 @@ class AbinitFlow(Node):
         kwargs:
             if empty we use the user configuration file.
             if filepath in kwargs we init the scheduler from file.
-            else pass **kwargs to PyFlowScheduler.__init__
+            else pass **kwargs to :class:`PyFlowScheduler` __init__ method.
         """
         from .launcher import PyFlowScheduler
 
@@ -1104,43 +1070,38 @@ class AbinitFlow(Node):
         return sched
 
 
-class G0W0WithQptdmFlow(AbinitFlow):
-    """
-    Build an `AbinitFlow` for one-shot G0W0 calculations.
-    The computation of the q-points for the screening is parallelized with qptdm
-    i.e. we run independent calculation for each q-point and then we merge
-    the final results.
+class G0W0WithQptdmFlow(Flow):
 
-    Args:
-        workdir:
-            Working directory.
-        manager:
-            `TaskManager` object used to submit the jobs
-        scf_input:
-            Input for the GS SCF run.
-        nscf_input:
-            Input for the NSCF run (band structure run).
-        scr_input:
-            Input for the SCR run.
-        sigma_inputs:
-            Input(s) for the SIGMA run(s).
-    """
     def __init__(self, workdir, manager, scf_input, nscf_input, scr_input, sigma_inputs):
+        """
+        Build a `Flow` for one-shot G0W0 calculations.
+        The computation of the q-points for the screening is parallelized with qptdm
+        i.e. we run independent calculation for each q-point and then we merge
+        the final results.
+
+        Args:
+            workdir: Working directory.
+            manager: :class:`TaskManager` object used to submit the jobs
+            scf_input: Input for the GS SCF run.
+            nscf_input: Input for the NSCF run (band structure run).
+            scr_input: Input for the SCR run.
+            sigma_inputs: Input(s) for the SIGMA run(s).
+        """
         super(G0W0WithQptdmFlow, self).__init__(workdir, manager)
 
-        # Register the first workflow (GS + NSCF calculation)
-        bands_work = self.register_work(BandStructureWorkflow(scf_input, nscf_input))
+        # Register the first work (GS + NSCF calculation)
+        bands_work = self.register_work(BandStructureWork(scf_input, nscf_input))
 
-        # Register the callback that will be executed the workflow for the SCR with qptdm.
+        # Register the callback that will be executed the work for the SCR with qptdm.
         scr_work = self.register_work_from_cbk(cbk_name="cbk_qptdm_workflow", cbk_data={"input": scr_input},
-                                               deps={bands_work.nscf_task: "WFK"}, work_class=QptdmWorkflow)
+                                               deps={bands_work.nscf_task: "WFK"}, work_class=QptdmWork)
 
-        # The last workflow contains a list of SIGMA tasks
-        # that will use the data produced in the previous two workflows.
+        # The last work contains a list of SIGMA tasks
+        # that will use the data produced in the previous two works.
         if not isinstance(sigma_inputs, (list, tuple)):
             sigma_inputs = [sigma_inputs]
 
-        sigma_work = Workflow()
+        sigma_work = Work()
         for sigma_input in sigma_inputs:
             sigma_work.register(sigma_input, deps={bands_work.nscf_task: "WFK", scr_work: "SCR"})
         self.register_work(sigma_work)
@@ -1152,11 +1113,11 @@ class G0W0WithQptdmFlow(AbinitFlow):
         This callback is executed by the flow when bands_work.nscf_task reaches S_OK.
 
         It computes the list of q-points for the W(q,G,G'), creates nqpt tasks
-        in the second workflow (QptdmWorkflow), and connect the signals.
+        in the second work (QptdmWork), and connect the signals.
         """
         scr_input = cbk.data["input"]
         # Use the WFK file produced by the second
-        # Task in the first Workflow (NSCF step).
+        # Task in the first Work (NSCF step).
         nscf_task = self[0][1]
         wfk_file = nscf_task.outdir.has_abiext("WFK")
 
@@ -1179,7 +1140,8 @@ class FlowCallback(object):
     This object implements the callbacks executeed by the flow when
     particular conditions are fulfilled. See on_dep_ok method of Flow.
 
-    .. note:
+    .. note::
+
         I decided to implement callbacks via this object instead of a standard
         approach based on bound methods because:
 
@@ -1193,20 +1155,16 @@ class FlowCallback(object):
     def __init__(self, func_name, flow, deps, cbk_data):
         """
         Args:
-            func_name:
-                String with the name of the callback to execute.
-                func_name must be a bound method of flow with signature:
+            func_name: String with the name of the callback to execute.
+                       func_name must be a bound method of flow with signature:
 
-                    func_name(self, cbk)
+                            func_name(self, cbk)
 
-                where self is the Flow instance and cbk is the callback
-            flow:
-                Reference to the `Flow`
-            deps:
-                List of dependencies associated to the callback
-                The callback is executed when all dependencies reach S_OK.
-            cbk_data:
-                Dictionary with additional data that will be passed to the callback via self.
+                       where self is the Flow instance and cbk is the callback
+            flow: Reference to the :class:`Flow`
+            deps: List of dependencies associated to the callback
+                  The callback is executed when all dependencies reach S_OK.
+            cbk_data: Dictionary with additional data that will be passed to the callback via self.
         """
         self.func_name = func_name
         self.flow = flow
@@ -1254,96 +1212,107 @@ class FlowCallback(object):
 
 
 # Factory functions.
-def bandstructure_flow(workdir, manager, scf_input, nscf_input, dos_inputs=None):
+def bandstructure_flow(workdir, manager, scf_input, nscf_input, dos_inputs=None, flow_class=Flow):
     """
-    Build an `AbinitFlow` for band structure calculations.
+    Build a :class:`Flow` for band structure calculations.
 
     Args:
-        workdir:
-            Working directory.
-        manager:
-            `TaskManager` object used to submit the jobs
-        scf_input:
-            Input for the GS SCF run.
-        nscf_input:
-            Input for the NSCF run (band structure run).
-        dos_inputs:
-            Input(s) for the NSCF run (dos run).
+        workdir: Working directory.
+        manager: :class:`TaskManager` object used to submit the jobs
+        scf_input: Input for the GS SCF run.
+        nscf_input: Input for the NSCF run (band structure run).
+        dos_inputs: Input(s) for the NSCF run (dos run).
+        flow_class: Flow class
 
     Returns:
-        `AbinitFlow`
+        :class:`Flow` object
     """
-    flow = AbinitFlow(workdir, manager)
-    work = BandStructureWorkflow(scf_input, nscf_input, dos_inputs=dos_inputs)
+    flow = flow_class(workdir, manager)
+    work = BandStructureWork(scf_input, nscf_input, dos_inputs=dos_inputs)
     flow.register_work(work)
     return flow.allocate()
 
 
-def g0w0_flow(workdir, manager, scf_input, nscf_input, scr_input, sigma_inputs):
+def g0w0_flow(workdir, manager, scf_input, nscf_input, scr_input, sigma_inputs, flow_class=Flow):
     """
-    Build an `AbinitFlow` for one-shot $G_0W_0$ calculations.
+    Build an :class:`Flow` for one-shot $G_0W_0$ calculations.
 
     Args:
-        workdir:
-            Working directory.
-        manager:
-            `TaskManager` object used to submit the jobs
-        scf_input:
-            Input for the GS SCF run.
-        nscf_input:
-            Input for the NSCF run (band structure run).
-        scr_input:
-            Input for the SCR run.
-        sigma_inputs:
-            List of inputs for the SIGMA run.
+        workdir: Working directory.
+        manager: :class:`TaskManager` object used to submit the jobs.
+        scf_input: Input for the GS SCF run.
+        nscf_input: Input for the NSCF run (band structure run).
+        scr_input: Input for the SCR run.
+        sigma_inputs: List of inputs for the SIGMA run.
+        flow_class: Flow class
 
     Returns:
-        `AbinitFlow`
+        :class:`Flow` object
     """
-    flow = AbinitFlow(workdir, manager)
-    work = G0W0_Workflow(scf_input, nscf_input, scr_input, sigma_inputs)
+    flow = flow_class(workdir, manager)
+    work = G0W0Work(scf_input, nscf_input, scr_input, sigma_inputs)
     flow.register_work(work)
     return flow.allocate()
 
 
-def phonon_flow(workdir, manager, scf_input, ph_inputs):
+def phonon_flow(workdir, manager, scf_input, ph_inputs, with_nscf=False, with_ddk=False, with_dde=False, flow_class=Flow):
     """
-    Build an `AbinitFlow` for phonon calculations.
+    Build an `Flow` for phonon calculations.
 
     Args:
-        workdir:
-            Working directory.
-        manager:
-            `TaskManager` used to submit the jobs
-        scf_input:
-            Input for the GS SCF run.
-        ph_inputs:
-            List of Inputs for the phonon runs.
+        workdir: Working directory.
+        manager: :class:`TaskManager` used to submit the jobs
+        scf_input: Input for the GS SCF run.
+        ph_inputs: List of Inputs for the phonon runs.
+        with_nscf: add an nscf task in front of al phonon tasks to make sure the q point is covered
+        with_ddk: add the ddk step
+        with_dde: add the dde step it the dde is set ddk is switched on automatically
+        flow_class: Flow class
 
     Returns:
-        `AbinitFlow`
+        :class:`Flow` object
     """
+    if with_dde:
+        with_ddk = True
+
     natom = len(scf_input.structure)
 
-    # Create the container that will manage the different workflows.
-    flow = AbinitFlow(workdir, manager)
+    # Create the container that will manage the different work.
+    flow = flow_class(workdir, manager)
 
-    # Register the first workflow (GS calculation)
-    scf_task = flow.register_task(scf_input, task_class=ScfTask)
+    # Register the first work (GS calculation)
+    # register_task creates a work for the task, registers it to the flow and returns the work
+    # the 0the element of the work is the task
+    scf_task = flow.register_task(scf_input, task_class=ScfTask)[0]
 
-    # Build a temporary workflow with a shell manager just to run 
+    # Build a temporary work with a shell manager just to run
     # ABINIT to get the list of irreducible pertubations for this q-point.
     shell_manager = manager.to_shell_manager(mpi_procs=1)
 
+    if with_ddk:
+        logger.info('add ddk')
+        ddk_input = ph_inputs[0].deepcopy()
+        ddk_input.set_variables(qpt=[0, 0, 0], rfddk=1, rfelfd=2, rfdir=[1, 1, 1])
+        ddk_task = flow.register_task(ddk_input, deps={scf_task: 'WFK'}, task_class=DdkTask)[0]
+
+    if with_dde:
+        logger.info('add dde')
+        dde_input = ph_inputs[0].deepcopy()
+        dde_input.set_variables(qpt=[0, 0, 0], rfddk=1, rfelfd=2)
+        dde_input_idir = dde_input.deepcopy()
+        dde_input_idir.set_variables(rfdir=[1, 1, 1])
+        dde_task = flow.register_task(dde_input, deps={scf_task: 'WFK', ddk_task: 'DDK'}, task_class=DdeTask)[0]
+
     if not isinstance(ph_inputs, (list, tuple)):
         ph_inputs = [ph_inputs]
 
     for i, ph_input in enumerate(ph_inputs):
+
         fake_input = ph_input.deepcopy()
 
         # Run abinit on the front-end to get the list of irreducible pertubations.
         tmp_dir = os.path.join(workdir, "__ph_run" + str(i) + "__")
-        w = PhononWorkflow(workdir=tmp_dir, manager=shell_manager)
+        w = PhononWork(workdir=tmp_dir, manager=shell_manager)
         fake_task = w.register(fake_input)
 
         # Use the magic value paral_rf = -1 to get the list of irreducible perturbations for this q-point.
@@ -1358,17 +1327,30 @@ def phonon_flow(workdir, manager, scf_input, ph_inputs):
 
         # Parse the file to get the perturbations.
         irred_perts = yaml_read_irred_perts(fake_task.log_file.path)
-        print(irred_perts)
+        logger.info(irred_perts)
 
         w.rmtree()
 
-        # Now we can build the final list of workflows:
-        # One workflow per q-point, each workflow computes all 
+        # Now we can build the final list of works:
+        # One work per q-point, each work computes all 
         # the irreducible perturbations for a singe q-point.
-        work_qpt = PhononWorkflow()
+
+        work_qpt = PhononWork()
+
+        if with_nscf:
+            nscf_input = copy.deepcopy(scf_input)
+            nscf_input.set_variables(kptopt=3, iscf=-3, qpt=irred_perts[0]['qpt'], nqpt=1)
+            nscf_task = work_qpt.register_nscf_task(nscf_input, deps={scf_task: "DEN"})
+            deps = {nscf_task: "WFQ", scf_task: "WFK"}
+        else:
+            deps = {scf_task: "WFK"}
+
+        if with_ddk:
+            deps[ddk_task] = 'DDK'
+
+        logger.info(irred_perts[0]['qpt'])
 
         for irred_pert in irred_perts:
-            print(irred_pert)
             new_input = ph_input.deepcopy()
 
             #rfatpol   1 1   # Only the first atom is displaced
@@ -1389,8 +1371,16 @@ def phonon_flow(workdir, manager, scf_input, ph_inputs):
                 rfatpol=rfatpol,
             )
 
-            work_qpt.register(new_input, deps={scf_task: "WFK"}, task_class=PhononTask)
+            if with_ddk:
+                new_input.set_variables(rfelfd=3)
+
+            work_qpt.register(new_input, deps=deps, task_class=PhononTask)
 
         flow.register_work(work_qpt)
+
+        #if ana_input is not None:
+        #    merge_input = {}
+        #    qp_merge_task = flow.register_task(merge_input, deps={work_qpt: "DDB"}, task_class=QpMergeTask)
+        #    flow.register_task(ana_input, deps={qp_merge_task: "DDB"}, task_class=AnaddbTask)
                                             
     return flow.allocate()
