@@ -843,7 +843,7 @@ class Kpoints(PMGSONable):
             structure (Structure): Input structure
             kppa (int): Grid density
             force_gamma (bool): Force a gamma centered mesh (default is to
-                use gamma only for hexagonal cells)
+                use gamma only for hexagonal cells or odd meshes)
 
         Returns:
             Kpoints
@@ -927,6 +927,27 @@ class Kpoints(PMGSONable):
         num_kpts = 0
         return Kpoints(comment, num_kpts, style, [num_div], [0, 0, 0])
 
+    @staticmethod
+    def automatic_density_by_vol(structure, kppvol, force_gamma=False):
+        """
+        Returns an automatic Kpoint object based on a structure and a kpoint
+        density per inverse Angstrom of reciprocal cell.
+
+        Algorithm:
+            Same as automatic_density()
+
+        Args:
+            structure (Structure): Input structure
+            kppvol (int): Grid density per Angstrom^(-3) of reciprocal cell
+            force_gamma (bool): Force a gamma centered mesh
+
+        Returns:
+            Kpoints
+        """
+        vol = structure.lattice.reciprocal_lattice.volume
+        kppa = int(round(kppvol * vol * structure.num_sites))
+        return Kpoints.automatic_density(structure, kppa, force_gamma=force_gamma)
+
     def automatic_linemode(divisions, ibz):
         """
         Convenient static constructor for a KPOINTS in mode line_mode.
@@ -975,7 +996,21 @@ class Kpoints(PMGSONable):
             Kpoints object
         """
         with zopen(filename, "rt") as f:
-            lines = [line.strip() for line in f.readlines()]
+            return Kpoints.from_string(f.read())
+
+    @staticmethod
+    def from_string(string):
+        """
+        Reads a Kpoints object from a KPOINTS string.
+
+        Args:
+            string (str): KPOINTS string.
+
+        Returns:
+            Kpoints object
+        """
+        lines = [line.strip() for line in string.splitlines()]
+
         comment = lines[0]
         num_kpts = int(lines[1].split()[0].strip())
         style = lines[2].lower()[0]
